#ifndef ccblogtrail_h
#define ccblogtrail_h

/*
 * CCBLogTrail objects keep a record of the checksums of up to a given
 * number of message strings per logging statement, and thus allow the
 * caller to check for redundantly or excessively reported messages
 * from a given statement.
 */
typedef struct CCBLogTrail CCBLogTrail;

CCBLogTrail *new_CCBLogTrail(size_t maxstmt, size_t maxmsg);
CCBLogTrail *del_CCBLogTrail(CCBLogTrail *lt);

/*
 * Discard all recorded message checksums.
 */
int ccb_lt_purge(CCBLogTrail *lt);

/*
 * Compute the checksum of a new message generated by a given
 * statement, and compare it to the checksums of previously registered
 * messages from that statement. If the message has been reported
 * before, or too many messages have been reported by the specified
 * statement, return 0 to indicate that the message should be
 * discarded. Otherwise return non-zero.
 */
int ccb_lt_verify_msg(CCBLogTrail *lt, unsigned long statement,
		      const char *text);

/*
 * Specify the interval at which recorded checksums should be purged.
 */
int ccb_lt_lifetime(CCBLogTrail *lt, unsigned long seconds);

#endif
