#ifndef iptable_h
#define iptable_h

#include <netinet/in.h>  /* in_addr_t */
/*
 * CCBIPTable objects record a list of IP addresses (each address
 * potentially containing one or more wild-carded fields).
 */
typedef struct CCBIPTable CCBIPTable;

/*
 * Create an IP-address table, and fill it from the contents of a
 * specified file. The file should contain a list of numeric IP
 * addresses, with one address per line. Numeric fields in the
 * addresses can be wildcarded by replacing them with an asterix.
 * Thus 192.168.168.18 and 192.168.*.* are both legal entries
 * specifications.
 */
CCBIPTable *new_CCBIPTable(const char *dir, const char *filename,
			   char *errmsg, size_t errdim);

/*
 * Delete a table of IP addresses.
 */
CCBIPTable *del_CCBIPTable(CCBIPTable *ip);

/*
 * Check wether a given numeric IP address is covered by a specified table
 * of IP addresses, and return true (non-zero) if so.
 */
int ccb_valid_manager_address(CCBIPTable *ip, const char *addr);

#endif
